==> SQUADD_1.0.0.zip: SQUADD/doc/SQUADD_ERK.R <==
###################################################
### chunk number 1: source package
###################################################
#line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"
library(SQUADD)


###################################################
### chunk number 2: instance
###################################################
#line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"
# construct instance of SquadSimResServiceImpl
fpath <- system.file("extdata", package="SQUADD")
folder <- file.path(fpath,"data_ERK")
sim <- simResService (folder=folder,
			  time= 20,
			  ncolor=5,
     		 legend= c("EGF", "ERK", "MEK", "RAF"),
  			 indexDeno=1,
			 method="lowess")


###################################################
### chunk number 3: SimMatrix
###################################################
#line 98 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"
sim["selectNode"] <-c("ERK", "MEK", "RAF")
plotSimMatrix(sim)


###################################################
### chunk number 4: fittedValues
###################################################
#line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"
tab <- getFittedTable(sim)


###################################################
### chunk number 5: PredMap
###################################################
#line 147 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"
plotPredMap(sim)


###################################################
### chunk number 6: FigPredMap
###################################################
#line 154 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"
#line 147 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw#from line#154#"
plotPredMap(sim)
#line 155 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"


###################################################
### chunk number 7: 
###################################################
#line 168 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpFdRPNt/R.INSTALL6e0851d2/SQUADD/inst/doc/SQUADD_ERK.Rnw"
sessionInfo()

==> SQUADD_1.2.0.zip: SQUADD/doc/SQUADD_ERK.R <==
###################################################
### chunk number 1: source package
###################################################
#line 63 "SQUADD_ERK.Rnw"
library(SQUADD)


###################################################
### chunk number 2: instance
###################################################
#line 76 "SQUADD_ERK.Rnw"
# construct instance of SquadSimResServiceImpl
fpath <- system.file("extdata", package="SQUADD")
folder <- file.path(fpath,"data_ERK")
sim <- simResService (folder=folder,
			  time= 20,
			  ncolor=5,
     		 legend= c("EGF", "ERK", "MEK", "RAF"),
  			 indexDeno=1,
			 method="lowess")


###################################################
### chunk number 3: SimMatrix
###################################################
#line 98 "SQUADD_ERK.Rnw"
sim["selectNode"] <-c("ERK", "MEK", "RAF")
plotSimMatrix(sim)


###################################################
### chunk number 4: fittedValues
###################################################
#line 126 "SQUADD_ERK.Rnw"
tab <- getFittedTable(sim)


###################################################
### chunk number 5: PredMap
###################################################
#line 147 "SQUADD_ERK.Rnw"
plotPredMap(sim)


###################################################
### chunk number 6: FigPredMap
###################################################
#line 154 "SQUADD_ERK.Rnw"
#line 147 "SQUADD_ERK.Rnw"
plotPredMap(sim)
#line 155 "SQUADD_ERK.Rnw"


###################################################
### chunk number 7: 
###################################################
#line 168 "SQUADD_ERK.Rnw"
sessionInfo()
